Get Metabolites
Source:R/AllGenerics.R, R/methods-accessors-cm.R, R/methods-accessors-cma.R, and 1 more
metabolites.RdRetrieves the metabolites involved in the metabolic
network. For ConsortiumMetabolism objects, the
result can optionally be restricted to a specific
species and/or direction ("consumed" or
"produced").
Usage
metabolites(object, ...)
# S4 method for class 'ConsortiumMetabolism'
metabolites(
object,
species = NULL,
direction = c("all", "consumed", "produced")
)
# S4 method for class 'ConsortiumMetabolismAlignment'
metabolites(object)
# S4 method for class 'ConsortiumMetabolismSet'
metabolites(object)Arguments
- object
A
ConsortiumMetabolism,ConsortiumMetabolismSet, orConsortiumMetabolismAlignmentobject.- ...
Additional arguments. For
ConsortiumMetabolism:species(character scalar; restrict to metabolites involved with this species) anddirection(one of"all","consumed", or"produced"; defaults to"all").- species
Optional length-1 character scalar. If supplied, restrict the result to metabolites involved in pathways that include this species. Defaults to
NULL(all species).- direction
One of
"all"(default),"consumed", or"produced". Restricts the result to metabolites in the given role across the (possibly species-filtered) pathways.